#! -*- coding: utf-8 *-

GIST_BASE_URL = "https://api.github.com"

endpoints = {
    'gist_post':
        {
            'url': '/'.join([GIST_BASE_URL, 'gists']),
            'method': 'POST',
        }
}



#! /usr/bin/env python
#! -*- coding: utf-8 -*-

import requests
from gist.endpoints import endpoints
import sys

def main():
    try:
        if not sys.stdin.isatty():
            content = []
            while 1:
                 content.append(sys.stdin.xreadlines().next())
    except StopIteration:
        pass




#! /usr/bin/env python
#! -*- coding: utf-8 *-*-

import sys
from setuptools import Command, setup, find_packages

readme = open('README.rst', 'r').read()
setup(
    name='gist',
    version='0.0.5',
    url='https://github.com/kracekumar/gist',
    license='BSD',
    author='kracekumar',
    author_email='me@kracekumar',
    description='Command Line Interface for pasting to gist.github.com',
    long_description=readme,
    packages=find_packages(),
    install_requires=['requests', 'argparse'],
    entry_points={
        'console_scripts': [
            'gist = gist.commands:main',
            ]
    },
    classifiers=[
          'Development Status :: 2 - Pre-Alpha',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'License :: OSI Approved :: BSD License',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Unix',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.5',
          'Programming Language :: Python :: 2.6',
          'Topic :: Software Development',
          'Topic :: Software Development :: Build Tools',
          'Topic :: Software Development :: Libraries',
          'Topic :: Software Development :: Libraries :: Python Modules',

    ],
    )



#! /usr/bin/env python
#! -*- coding: utf-8 -*-

import requests
from gist.endpoints import endpoints

def gist_post(public = True, files, description = None, ):
    if public:
        try:
            url = endpoints['gist_post']['url']
            r = requests.post
        except KeyError:
            raise KeyError("URL to POST is missing")
